#############################################################################
#
# Copyright (c) 2010 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import grok
import zope.interface

class NoRequireView(grok.View):
    grok.context(zope.interface.Interface)

    def render(self):
        pass

class NoRequirePage(grok.Page):
    grok.context(zope.interface.Interface)

    def render(self):
        pass

class NoRequireViewletManager(grok.ViewletManager):
    grok.context(zope.interface.Interface)

    def render(self):
        pass

class NoRequireViewlet(grok.Viewlet):
    grok.context(zope.interface.Interface)
    grok.viewletmanager(NoRequireViewletManager)

    def render(self):
        pass

class NoRequireForm(grok.Form):
    grok.context(zope.interface.Interface)

class NoRequireAddForm(grok.AddForm):
    grok.context(zope.interface.Interface)

class NoRequireEditForm(grok.EditForm):
    grok.context(zope.interface.Interface)

class NoRequireXMLRPC(grok.XMLRPC):
    grok.context(zope.interface.Interface)

    def foobar(self):
        pass

class NoRequireREST(grok.REST):
    grok.context(zope.interface.Interface)

    def foobar(self):
        pass

class NoRequireJSON(grok.JSON):
    grok.context(zope.interface.Interface)

    def foobar(self):
        pass

class NoRequireView(grok.View):
    grok.context(zope.interface.Interface)

    def render(self):
        pass

class RequireView(grok.View):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

    def render(self):
        pass

class RequirePage(grok.Page):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

    def render(self):
        pass

class RequireForm(grok.Form):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

class RequireAddForm(grok.AddForm):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

class RequireEditForm(grok.EditForm):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

class RequireXMLRPC(grok.XMLRPC):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

    def foobar(self):
        pass

class RequireREST(grok.REST):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

    def foobar(self):
        pass

class RequireJSON(grok.JSON):
    grok.context(zope.interface.Interface)
    grok.require('zope.Public')

    def foobar(self):
        pass

class RequireOnMethodXMLRPC(grok.XMLRPC):
    grok.context(zope.interface.Interface)

    @grok.require('zope.Public')
    def foobar(self):
        pass

class RequireOnMethodREST(grok.REST):
    grok.context(zope.interface.Interface)

    @grok.require('zope.Public')
    def foobar(self):
        pass

class RequireOnMethodJSON(grok.JSON):
    grok.context(zope.interface.Interface)

    @grok.require('zope.Public')
    def foobar(self):
        pass



import os.path

from setuptools import setup, find_packages

version = '3.0.0'


detailed = open(
    os.path.join('src', 'megrok', 'strictrequire', 'README.txt')).read()


changes = open('CHANGES.txt').read()


long_description = '\n\n'.join([detailed, changes, ''])


tests_require = [
    'zope.component',
    'zope.interface',
    'zope.securitypolicy',
    'zope.testing',
    ]


setup(
    name='megrok.strictrequire',
    version=version,
    description=(
        'Checks that all grokked "view-like" components '
        'require a permission.'),
    long_description=long_description,
    classifiers=[],
    keywords=[],
    author='The Health Agency',
    author_email='techniek@thehealthagency.com',
    url='http://www.thehealthagency.com',
    license='ZPL 2.1',
    package_dir={'': 'src'},
    namespace_packages=['megrok'],
    packages=find_packages('src'),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'martian',
        'grok >= 3.0',
        ],
    extras_require={
        'test': tests_require
        },
    tests_require=tests_require,
    entry_points={},
    )



#############################################################################
#
# Copyright (c) 2010 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import doctest
import megrok.strictrequire.tests
import unittest
import zope.component.testlayer

from zope.testing import renormalizing


layer = zope.component.testlayer.ZCMLFileLayer(megrok.strictrequire.tests)

checker = renormalizing.RENormalizing()

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(
        doctest.DocFileSuite(
            'checkrequire.txt',
            checker=checker,
            optionflags=(
                doctest.NORMALIZE_WHITESPACE +
                doctest.ELLIPSIS +
                renormalizing.IGNORE_EXCEPTION_MODULE_IN_PYTHON2)))
    suite.layer = layer
    return suite
